==> asksuite-core-1.0.117.tgz: package/processing.natural.js <==
const apiai = require("apiai");
const Util = require('./util');

module.exports = function (config) {


    let resolver = {};

    const AsksuiteTranslator = require('./translator')(config);
    const AsksuiteUtil = require('./asksuite.util')(config);
    const KeywordMatcher = require('./keyword_interpreter/keyword-matcher')(config)


    const DialogFlow = apiai(config.apiAI_clientAcessToken);

    resolver.resolve = async function resolveText(userId, text, companyIntents, language) {

        return new Promise(async (resolve, reject) => {

            let intents = companyIntents;

            if (text.length < 80) {
                let lang =  AsksuiteUtil.defineLanguage(language);

                if (lang != "pt-br"){
                    text = await AsksuiteTranslator.googleTranslateIfNeed(text, lang)
                }


                let msg = Util.replaceIfIsPhrase(text.toLowerCase());

                console.log(msg);

                var request = DialogFlow.textRequest(msg, {
                    sessionId: userId,
                    resetContexts: true
                });

                request.on('response', function (response) {

                    let intentBot = intents.find(item => {
                        return item.intent == response.result.metadata.intentName;
                    });

                    if (intentBot) {
                        Object.assign(intentBot, response.result.parameters);
                        resolve( intentBot)

                    } else {

                        let intentLargeFixedName = "naoentendi";
                        let intentBot = intents.find(item => {
                            return item.intent == intentLargeFixedName
                        });

                        reject(intentBot);
                    }

                });

                request.on('error', function (error) {
                    console.log(error);
                    reject();
                });

                request.end();
            } else {

                let intentLargeFixedName = "naoentendi_grande";
                let intentBot = intents.find(item => {
                    return item.intent == intentLargeFixedName
                });

                if (intentBot) {
                    resolve( intentBot)
                } else {
                    reject()
                }
            }

        })

    };

    resolver.tryToResolveTextByKeywords = async function(text, intents, expressions, globalCache){

        return new Promise( async (resolve, reject) => {

            let keyWordMatch = await KeywordMatcher.getIntent(text, expressions, globalCache);

            if (keyWordMatch && keyWordMatch.length > 0){

                let intentBot = intents.find(item => {
                    return item.intent == keyWordMatch[0].intent;
                });

                if (intentBot) {
                    resolve( intentBot)
                } else {
                    reject();
                }
            }
        })

    };
    return resolver;
}

==> asksuite-core-1.0.139.tgz: package/processing.natural.js <==
const apiai = require("apiai");
const Util = require('./util');

module.exports = function (config) {


    let resolver = {};

    const AsksuiteTranslator = require('./translator')(config);
    const AsksuiteUtil = require('./asksuite.util')(config);
    const KeywordMatcher = require('./keyword_interpreter/keyword-matcher')(config)


    const DialogFlow = apiai(config.apiAI_clientAcessToken);

    resolver.resolve = async function resolveText(userId, text, companyIntents, language) {

        return new Promise(async (resolve, reject) => {

            let intents = companyIntents;

            if (text.length < 80) {
                let lang =  AsksuiteUtil.defineLanguage(language);

                if (lang != "pt-br"){
                    text = await AsksuiteTranslator.googleTranslateIfNeed(text, lang)
                }


                let msg = Util.replaceIfIsPhrase(text.toLowerCase());

                console.log(msg);

                var request = DialogFlow.textRequest(msg, {
                    sessionId: userId,
                    resetContexts: true
                });

                request.on('response', function (response) {

                    let intentBot = intents.find(item => {
                        return item.intent == response.result.metadata.intentName;
                    });

                    if (intentBot) {

                        let cloneIntent = JSON.parse(JSON.stringify(intentBot));
                        Object.assign(cloneIntent, response.result.parameters);
                        resolve( cloneIntent)

                    } else {

                        let intentLargeFixedName = "naoentendi";
                        let intentBot = intents.find(item => {
                            return item.intent == intentLargeFixedName
                        });

                        reject(intentBot);
                    }

                });

                request.on('error', function (error) {
                    console.log(error);
                    reject();
                });

                request.end();
            } else {

                let intentLargeFixedName = "naoentendi_grande";
                let intentBot = intents.find(item => {
                    return item.intent == intentLargeFixedName
                });

                if (intentBot) {
                    resolve( intentBot)
                } else {
                    reject()
                }
            }

        })

    };

    resolver.tryToResolveTextByKeywords = async function(text, intents, expressions, globalCache){

        return new Promise( async (resolve, reject) => {

            let keyWordMatch = await KeywordMatcher.getIntent(text, expressions, globalCache);

            if (keyWordMatch && keyWordMatch.length > 0){

                let intentBot = intents.find(item => {
                    return item.intent == keyWordMatch[0].intent;
                });

                if (intentBot) {
                    resolve( intentBot)
                } else {
                    reject();
                }
            }
        })

    };
    return resolver;
}
